@@ -2,7 +2,6 @@ import requests
 import time
 import signal
 import subprocess
-from multiprocessing import  current_process
 from threading import Thread
 import json
 try:
@@ -27,7 +26,7 @@ def post_task_status(hisId, jobState, jobResult, master_data):
         r = requests.post(url=url, json=data, headers=headers)
         response_text = json.loads(str(r.text))
         if response_text["statusCode"] == "00":
-            print("update task status successful")
+            print("post task status successful")
             return 0
         print("post task status failed: ", r.text)
     except Exception as e:
@@ -99,7 +98,7 @@ def task_runner(master_data):
     print("---------------")
     print("task_runner:", master_data)
     print("---------------")
-    write_pid(current_process().pid, task_pidfile)
+    write_pid(task_pidfile)
     queue = Queue(maxsize=50)
     producer = Thread(target=task_producer, args=(queue, master_data))
     consumer = Thread(target=task_consumer, args=(queue, master_data))
